"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.memoize = void 0;
function memoize(fn, resolver) {
    const memoized = function (...args) {
        const key = resolver.apply(this, args);
        const { cache } = memoized;
        if (cache.has(key)) {
            return cache.get(key);
        }
        const result = fn.apply(this, args);
        memoized.cache.set(key, result);
        return memoized;
    };
    memoized.cache = new memoize.Cache();
    return memoized;
}
exports.memoize = memoize;
memoize.Cache = Map;
